@@ -1310,7 +1310,7 @@ class MAPHIS(QMainWindow):
         return execute
 
     def compute_regions3(self, reg_comp: RegionComputation, process_mode: ProcessType):
-        if not (can_execute := reg_comp.can_be_executed)[0]:
+        if not reg_comp.initialize() and not (can_execute := reg_comp.can_be_executed)[0]:
             QMessageBox.information(self, f'Cannot run {reg_comp.info.name}', can_execute[1])
             return
         if process_mode == ProcessType.ALL_PHOTOS:
