@@ -66,6 +66,9 @@ class Action:
             param_obj: Param = self.user_params_dict[param_key]
             param_obj.parse(param_value_str)
 
+    def initialize(self) -> bool:
+        return True
+
 
 class RegionComputation(Action):
     FOLDER = 'regions'
