@@ -16,7 +16,6 @@ from typing import Union, Optional, List, Literal, Dict, Tuple
 
 import PySide6
 import cv2
-import qimage2ndarray
 from PIL import Image
 from PySide6.QtCore import Qt, QAbstractItemModel, QObject, QModelIndex, Signal, QAbstractTableModel, QSize, \
     QTimer, QDir, QRegularExpression
@@ -25,6 +24,7 @@ from PySide6.QtWidgets import QApplication, QDialog, QDialogButtonBox, QComplete
     QStyledItemDelegate, QWidget, QStyleOptionViewItem, QLineEdit, QComboBox, QLabel, QHeaderView, QVBoxLayout, \
     QTableView
 
+from maphis import qimage2ndarray
 from maphis.common.image_operation_binding import ResizeWidget
 from maphis.common.label_image import LabelImgType
 from maphis.common.local_storage import IMAGE_REFEX, restructure_folder
@@ -37,7 +37,7 @@ from maphis.image_viewer import ImageViewer
 from maphis.import_utils import TempStorage, TempPhoto
 from maphis.thumbnail_storage import ThumbnailDelegate, ThumbnailStorage_
 from maphis.ui_import_dialog import Ui_ImportDialog
-from common.photo import Photo
+from maphis.common.photo import Photo
 
 TXT_EXTRACT_SCALE = 'Extract scale from scale markers'
 TXT_PLEASE_NAVIGATE_TO_PHOTOS = 'Please navigate to a folder with photos.'
