@@ -8,7 +8,6 @@ import PySide6
 import cv2
 import numba
 import numpy as np
-import qimage2ndarray
 import scipy
 from PySide6.QtCore import Qt, Signal, QRectF
 from PySide6.QtGui import QRegion, QBitmap, QImage, QColor, QPainter, QBrush, QTransform
@@ -18,6 +17,7 @@ from scipy import ndimage
 import skimage.morphology as M
 from skimage import io
 
+from maphis import qimage2ndarray
 from maphis.common.label_change import CommandEntry
 from maphis.common.layer import Layer
 from maphis.common.photo import Photo, LabelImg
