@@ -1,5 +1,7 @@
 import importlib
 import os
+import pathlib
+import shutil
 import sys
 import typing
 from typing import Set, Optional, Tuple
@@ -7,6 +9,7 @@ from typing import Set, Optional, Tuple
 import cv2
 import math
 import arthseg
+from common.download import DownloadDialog
 # import torch
 from numpy import ndarray
 import numpy as np
@@ -185,11 +188,23 @@ class UNetRegions(RegionComputation):
 
         return image
 
-    def predict(self, image: ndarray) -> ndarray:
+    def initialize(self) -> bool:
+        path = pathlib.Path(os.path.dirname(os.path.realpath(__file__)))
+        model_path = path / 'model.pt'
+        if not model_path.exists():
+            download = DownloadDialog("https://gitlab.fi.muni.cz/xmraz3/maphis_pekar_segmentation/-/raw/main/model.pt",
+                                      dst=model_path,
+                                      label='Downloading segmentation model',
+                                      title='First time initialization of plugin')
+            if not download.start():
+                shutil.rmtree(model_path)
+                return False
         if self.torch is None:
             self.torch = importlib.import_module('torch')
-            dir = os.path.dirname(os.path.realpath(__file__))
-            self.model = self.torch.jit.load(os.path.join(dir, 'model.pt'))
+            self.model = self.torch.jit.load(model_path)
+        return True
+
+    def predict(self, image: ndarray) -> ndarray:
         height_padding, width_padding = self.get_padding(image)
         image = self.add_padding(image, height_padding, width_padding)
 
